<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ca_ES">
<context>
    <name>ConfigureOSC</name>
    <message>
        <location filename="configureosc.ui" line="33"/>
        <source>OSC Plugin Configuration</source>
        <oldsource>Configure OSC Plugin</oldsource>
        <translation>Configurarció del Plugin OSC</translation>
    </message>
    <message>
        <location filename="configureosc.ui" line="47"/>
        <source>Universes Configuration</source>
        <translation>Configuració d&apos;Universos</translation>
    </message>
    <message>
        <location filename="configureosc.ui" line="60"/>
        <source>Interface</source>
        <translation>Interficie</translation>
    </message>
    <message>
        <location filename="configureosc.ui" line="65"/>
        <source>Universe</source>
        <translation>Univers</translation>
    </message>
    <message>
        <location filename="configureosc.ui" line="70"/>
        <source>Input Port</source>
        <translation>Port d&apos;Entrada</translation>
    </message>
    <message>
        <location filename="configureosc.ui" line="75"/>
        <source>Output Address</source>
        <translation>Direcció de Sortida</translation>
    </message>
    <message>
        <location filename="configureosc.ui" line="80"/>
        <source>Output Port</source>
        <translation>Port de Sortida</translation>
    </message>
    <message>
        <location filename="configureosc.ui" line="90"/>
        <source>Seconds to wait for an interface to be ready</source>
        <translation>Segons a esperar que estigui preparada una interfície</translation>
    </message>
    <message>
        <location filename="configureosc.ui" line="122"/>
        <source>Channel number calculator</source>
        <translation>Calculadora de número de canal</translation>
    </message>
    <message>
        <location filename="configureosc.ui" line="130"/>
        <source>OSC path</source>
        <translation>Ruta OSC</translation>
    </message>
    <message>
        <location filename="configureosc.ui" line="140"/>
        <source>Channel number</source>
        <translation>Número de canal</translation>
    </message>
    <message>
        <location filename="configureosc.cpp" line="88"/>
        <source>Inputs</source>
        <translation>Entrades</translation>
    </message>
    <message>
        <location filename="configureosc.cpp" line="94"/>
        <source>Outputs</source>
        <translation>Sortides</translation>
    </message>
    <message>
        <location filename="configureosc.cpp" line="176"/>
        <source>Invalid IP</source>
        <translation>IP Invàlida</translation>
    </message>
    <message>
        <location filename="configureosc.cpp" line="176"/>
        <source>%1 is not a valid IP.
Please fix it before confirming.</source>
        <translation>%1 no es una IP vàlida.
Si us plau arreglar-ho abans de confirmar.</translation>
    </message>
</context>
<context>
    <name>OSCPlugin</name>
    <message>
        <location filename="oscplugin.cpp" line="96"/>
        <source>This plugin provides input for devices supporting the OSC transmission protocol.</source>
        <translation>Aquest plugin proveeix entrada per dispositius que suporten el protocol de tansmissió OSC.</translation>
    </message>
    <message>
        <location filename="oscplugin.cpp" line="147"/>
        <location filename="oscplugin.cpp" line="280"/>
        <source>Status: Not open</source>
        <translation>Estat: No obert</translation>
    </message>
    <message>
        <location filename="oscplugin.cpp" line="150"/>
        <location filename="oscplugin.cpp" line="283"/>
        <source>Status: Open</source>
        <translation>Estat: Obert</translation>
    </message>
    <message>
        <location filename="oscplugin.cpp" line="152"/>
        <source>Packets sent: </source>
        <translation>Paquets enviats: </translation>
    </message>
    <message>
        <location filename="oscplugin.cpp" line="285"/>
        <source>Packets received: </source>
        <translation>Paquets rebuts: </translation>
    </message>
    <message>
        <location filename="oscplugin.cpp" line="143"/>
        <source>Output</source>
        <translation>Sortida</translation>
    </message>
    <message>
        <location filename="oscplugin.cpp" line="276"/>
        <source>Input</source>
        <translation>Entrada</translation>
    </message>
</context>
</TS>
